From f52e56ef44ced78fa954d490247450dc3cd43625 Mon Sep 17 00:00:00 2001
From: ahmedk <karim.ahmed@xfel.eu>
Date: Tue, 10 Oct 2023 16:53:52 +0200
Subject: [PATCH] improve docstring

---
 src/cal_tools/agipdlib.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/src/cal_tools/agipdlib.py b/src/cal_tools/agipdlib.py
index 29879a1ea..d58ac7ae6 100644
--- a/src/cal_tools/agipdlib.py
+++ b/src/cal_tools/agipdlib.py
@@ -334,7 +334,9 @@ class AgipdCtrlRuns:
                     f" with values of {values}, respectively.")
 
     def sort_dark_runs(self):
-        """Order dark runs based on PatternTypeIndex."""
+        """Order dark runs based on run patterns for Adaptive mode
+        or gain modes for Fixed mode.
+        """
         assert len(self.runs) == 3, f"AGIPD dark runs are expected to be 3. {len(self.runs)} runs are given."  # noqa
         # Expected patterns:
         # XRay: 0, DarkHG: 1, DarkMG: 2, DarkLG: 3, PC: 4 and CS: 5.
-- 
GitLab